@@ -196,7 +196,7 @@ class ConformationalAnalysis(object):
                     #  if this is raised, it means that you are looking into less than 10 structures
                     #  in that case, it will be tougher to find differentiation anyway
 
-                userClustermodel = clustering.clustering_model(userPCA_model, user_num_components,original_df)
+                userClustermodel,num_clusters_user = clustering.clustering_model(userPCA_model, user_num_components,original_df)
 
                 print()
                 print("Would you like to test with a different number of Clusters?")
@@ -242,9 +242,9 @@ class ConformationalAnalysis(object):
         break
 
     attempts_left = 10
-    os.chmod('omolab_conf_analysis-0.1.5/mGenerate_PyMOL_Session.sh', stat.S_IRWXU)
+    # os.chmod('mGenerate_PyMOL_Session.py', stat.S_IRWXU)
     print("______________________________________________________")
-    print("Importing structures to PyMol")
+    print("Sorting files by family")
     print("After reviewing the given plots, which of the files would you like to view in pyMol?")
     print("Enter the filename with  (ex. 'tamylOH_17.xyz'), with commas in between each name")
     print("______________________________________________________")
@@ -256,9 +256,10 @@ class ConformationalAnalysis(object):
 
             while pymolSession:
 
-                userPymolSession = pymol.generate_pymol(user_input_directory)
+                # userPymolSession = pymol.generate_pymol(user_input_directory)
+                user_FileFamilies = pymol.family_files(userClustermodel,num_clusters_user,user_input_directory)
                 print()
-                print("Would you like to generate a PyMol Session with different structures in the current directory?")
+                print("Would you like to generate a new file structure of your families?")
                 new_PyMolSession = input("Enter Y/N: ").upper()
                 print()
 
